"use strict";

const {app, BrowserWindow, ipcMain, dialog} = require("electron");
const path                                  = require("path");
const fs                                    = require("fs/promises");
const util                                  = require("util");

const {isDevelopment} = require("./Util");
const {parser}        = require("./Parser");

class WindowManager {
	mainWindow;
	windows;

	constructor() {
		this.mainWindow = null;
		this.windows    = [];

		app.whenReady().then(() => this.init());

		ipcMain.handle("WindowManager::openFile", async () => {
			if (!this.mainWindow)
				return null;

			const result = await dialog.showOpenDialog(this.mainWindow, {
				title   : "open file",
				filters : [
					{
						name       : "Markdown files",
						extensions : [".md"]
					}
				]
			});

			if (result.canceled || result.filePaths.length < 1)
				return null;

			const fileContents = await fs.readFile(result.filePaths[0], {encoding : "utf-8"});
			const basePath     = path.dirname(result.filePaths[0]);
			const data         = parser(fileContents);

			return [basePath, data];
		});
	}

	init() {
		this.mainWindow = WindowManager._CreateWindow({
			fullscreen     : false,
			fullscreenable : true,
			titleBarStyle  : "hiddenInset"
		});

		if (isDevelopment())
			this.mainWindow.loadURL("http://localhost:3000");
		else
			this.mainWindow.loadFile(`file://${path.join(__dirname, "ui", "build", "index.html")}`);
	}

	static _CreateWindow(options = null, parent = null) {
		const windowOptions = {
			width          : 800,
			height         : 600,
			show           : false,
			webPreferences : {
				contextIsolation : true,
				preload          : path.join(__dirname, "..", "contextAPI.js")
			},
			parent,
			...options
		};
		if (!parent)
			delete windowOptions.parent;
		const window = new BrowserWindow(windowOptions);
		window.once("ready-to-show", () => window.show());	

		return window;
	}
}

module.exports = WindowManager; 