import React, {useEffect, useState} from "react";

import SlidesList      from "./SlidesList";
import Mode            from "../models/Mode";
import Slide           from "./Slide";
import KeyboardControl from "./KeyboardControl";
import Blackout        from "./Blackout";
import NoFile          from "./NoFile";
import Toolbar         from "./Toolbar";

import SlideContext from "../shared/SlideContext";

const Ation = () => {
	const [mode, setMode]         = useState(Mode.NORMAL);
	const [deck, setDeck]         = useState([]);
	const [slide, setSlide]       = useState(0);
	const [basePath, setBasePath] = useState("");

	const openFile = async () => {
		const [basePath, slideDeck] = await window.api.openFile();

		if (!slideDeck)
			return;
		setBasePath(basePath);
		setDeck(slideDeck);
	}

	if (deck.length < 1)
		return <NoFile openFile={openFile} />;

	return (
		<SlideContext.Provider value={{slide, setSlide, mode, setMode, basePath}}>
			<section className={`window${mode === Mode.PRESENT ? " fullscreen" : ""}`}>
				<Toolbar openFile={openFile} />
				<SlidesList deck={deck} />
				<main className="main">
					<Slide data={deck[slide] || null} />
				</main>
			</section>
			<Blackout show={mode === Mode.BLACKOUT} />
			<KeyboardControl mode={mode} setMode={setMode} deck={deck} openFile={openFile} />
		</SlideContext.Provider>
	);
};

export default Ation;