import {useContext, useEffect} from "react";

import SlideContext from "../shared/SlideContext";
import Mode         from "../models/Mode";

const KeyboardControl = ({openFile, mode, setMode, deck}) => {
	const {slide, setSlide} = useContext(SlideContext);

	useEffect(() => {
		const keyHandler = event => {
			switch(event.key) {
				case "o":
					if (!event.metaKey && !event.ctrlKey)
						return;
					openFile();
					break;
				default:
					console.log(event.key);
			}
			if (!mode || !setMode || !deck)
				return;

			switch (event.key) {
				case "F5":
					if (deck.length <= 0)
						return;
					setSlide(0);
					document.documentElement.requestFullscreen();
					setMode(Mode.PRESENT);
					break;
				case "ArrowLeft":
				case "PageUp": // PRESENTER
					if (slide <= 0)
						return;
					setSlide(slide - 1);
					break;
				case "ArrowRight":
				case "PageDown": // PRESENTER
					if (slide >= deck.length -1)
						return;
					setSlide(slide + 1);
					break;
				case "b": // PRESENTER
					if (mode === Mode.NORMAL)
						return;
				 	setMode(mode === Mode.BLACKOUT ? Mode.PRESENT : Mode.BLACKOUT);
					break;
				default:
					return;
			}
		};

		const fullscreenHandler = () => {
			if (!document.fullscreenElement)
				setMode(Mode.NORMAL);
		};

		window.addEventListener("keydown", keyHandler);
		window.addEventListener("fullscreenchange", fullscreenHandler);

		return () => {
			window.removeEventListener("keydown", keyHandler);
			window.removeEventListener("fullscreenchange", fullscreenHandler);
		}

	}, [slide, setSlide, mode, setMode, deck]);
};

export default KeyboardControl;