import React, {useMemo, useContext} from "react";

import SyntaxHighlighter from "react-syntax-highlighter"
import {monokai}         from "react-syntax-highlighter/dist/esm/styles/hljs";

import SlideContext from "../shared/SlideContext";

const Children = ({items}) => {
	if (items instanceof Array)
		return <>{items.map((child, index) => <SlideItem item={child} key={index} />)}</>;
	return null;
};

const SlideItem = ({item}) => {
	const {basePath} = useContext(SlideContext);

	const content = useMemo(() => {
		console.log("ITEM",item);
		switch (item.type) {
			case "heading":
				return <h1><Children items={item.tokens} /></h1>
			case "list":
				if (item.ordered)
					return <ol><Children items={item.items} /></ol>
				else
					return <ul><Children items={item.items} /></ul>
			case "list_item":
				const prefix = item.task ? <span className={`checkbox${item.checked ? " checked" : ""}`}></span> : null;
				return <li className={item.task ? "task" : ""}>{prefix} <Children items={item.tokens} /></li>
			case "image":
				return (
					<figure>
						<img src={`slideimg://${basePath}/${item.href.replace(/\.\//, "")}`} alt={item.text} />
						{item.text?.length > 0 ?
							<figcaption>{item.text}</figcaption>
						: null}
					</figure>
				)
			case "blockquote":
				return <blockquote><Children items={item.tokens} /></blockquote>
			case "paragraph":
				return <p><Children items={item.tokens} /></p>
			case "code":
				return <SyntaxHighlighter style={monokai} language={item.lang}>{item.text}</SyntaxHighlighter>
			case "codespan":
				return <code>{item.text}</code>
			case "strong":
				return <b><Children items={item.tokens} /></b>
			case "em":
				return <i><Children items={item.tokens} /></i>
			case "text":
				return <>{item.text}</>
			default:
				return JSON.stringify(item);
		}
	}, [item, basePath]);

	return (
		<>
			{content}
		</>
	);
};

export default SlideItem;

/* {
	"type": "paragraph",
	"raw": "This is a very fancy **bold** keynote",
	"text": "This is a very fancy **bold** keynote",
	"tokens": [
		{
			"type": "text",
			"raw": "This is a very fancy ",
			"text": "This is a very fancy "
		},
		{
			"type": "strong",
			"raw": "**bold**",
			"text": "bold",
			"tokens": [
				{
					"type": "text",
					"raw": "bold",
					"text": "bold"
				}
			]
		},
		{
			"type": "text",
			"raw": " keynote",
			"text": " keynote"
		}
	]
} */