import React, {useEffect, useState, useCallback, useRef, useContext} from "react";

import Slide        from "./Slide";
import SlideContext from "../shared/SlideContext";

const SlidesList = ({deck}) => {
	const {slide, setSlide} = useContext(SlideContext);
	const container         = useRef();
	const [scale, setScale] = useState(1);

	const sizeChange = useCallback(() => {
		if (!container.current)
			return;
		const firstSlide = document.querySelector(".slides-list .slide");
		if (!firstSlide)
			return;

		const slideWidth  = firstSlide.clientWidth;
		const parentWidth = container.current.clientWidth;
		const targetWidth = parentWidth * 0.9;

		setScale(targetWidth / slideWidth);
	}, [container]);

	useEffect(() => {
		const resizeListener = () => {
			sizeChange();
		};

		window.addEventListener("resize", resizeListener);

		sizeChange();

		return () => window.removeEventListener("resize", resizeListener);
	}, [sizeChange, deck]);

	return (
		<aside className="slides-list" ref={container}>
			{deck.map((currentSlide, index) => (
				<div className="slide-wrap" key={index}>
					<Slide data={currentSlide} className={index === slide ? "active" : ""} style={{transform : `scale(${scale}) translateX(0)`}} onClick={() => setSlide(index)} />
				</div>
			))}
		</aside>
	);
};

export default SlidesList;